#
# Transfer interface type to target-side code

getsym $coff _iftype
PutLong $DEV $_iftype_addr $_iftype_pg $iftype

#
# Transfer controller base address to target-side code
#
getsym $coff _ctrlr_base
PutLong $DEV $_ctrlr_base_addr $_ctrlr_base_pg $ctrlr_base

#
# Initialization for MCBSP controller
#

#
# Transfer CS pin info to target-side code
#
getsym $coff _cs_port_address
getsym $coff _cs_port_mempage
getsym $coff _cs_port_width
getsym $coff _cs_port_bit
getsym $coff _cs_port_polarity

PutLong $DEV $_cs_port_address_addr $_cs_port_address_pg $cs_port_address
PutLong $DEV $_cs_port_mempage_addr $_cs_port_mempage_pg $cs_port_mempage
PutLong $DEV $_cs_port_width_addr $_cs_port_width_pg $cs_port_width
PutLong $DEV $_cs_port_bit_addr $_cs_port_bit_pg $cs_port_bit
PutLong $DEV $_cs_port_polarity_addr $_cs_port_polarity_pg $cs_port_polarity

#
# Initialize MCBSP controller itself to clock-stop mode (SPI)
#

#
# Calculate divide factor for ~ 1 MHz SCK
#

if { [string equal $cpu_type "TMS320C5500"] ||
     [string equal $cpu_type "TMS320C2800"] } {

  set mempage 1

  if { [string equal $cpu_type "TMS320C5500"] } {
    set mempage 2
  }

  puts "Initializing MCBSP controller to clock-stop mode (@$ctrlr_base)..." 

  set divisor [expr $periph_clock / 1000000]
  puts "Calculated SRGR value is $divisor"

  # SPCR1 = 0
  PutShort $DEV [expr $ctrlr_base + 0x04] $mempage 0x0
  # SPCR2 = 0x0200
  PutShort $DEV [expr $ctrlr_base + 0x05] $mempage 0x0200
  # pause
  after 10
  # SPCR1 = 0x1800
  PutShort $DEV [expr $ctrlr_base + 0x04] $mempage 0x1800
  # SPCR2 = 0
  PutShort $DEV [expr $ctrlr_base + 0x05] $mempage 0x0
  # PCR = 0x0A09
  PutShort $DEV [expr $ctrlr_base + 0x12] $mempage 0x0A09
  # RCR1 = 0x0000
  PutShort $DEV [expr $ctrlr_base + 0x06] $mempage 0x0000
  # RCR2 = 0x0001
  PutShort $DEV [expr $ctrlr_base + 0x07] $mempage 0x0001
  # XCR1 = 0x0000
  PutShort $DEV [expr $ctrlr_base + 0x08] $mempage 0x0000
  # XCR2 = 0x0001
  PutShort $DEV [expr $ctrlr_base + 0x09] $mempage 0x0001
  # SRGR1 = 0x000F
  PutShort $DEV [expr $ctrlr_base + 0x0A] $mempage $divisor
  # SRGR2 = 0x2000
  PutShort $DEV [expr $ctrlr_base + 0x0B] $mempage 0x2000
  # MCR1 = 0
  PutShort $DEV [expr $ctrlr_base + 0x0C] $mempage 0x0
  # MCR2 = 0
  PutShort $DEV [expr $ctrlr_base + 0x0D] $mempage 0x0
  # pause
  after 30
  # SPCR2 = 0x0240
  PutShort $DEV [expr $ctrlr_base + 0x05] $mempage 0x0240
  # pause
  after 200
  # SPCR1 = 0x1801
  PutShort $DEV [expr $ctrlr_base + 0x04] $mempage 0x1801
  # SPCR2 = 0x0241
  PutShort $DEV [expr $ctrlr_base + 0x05] $mempage 0x0241

}

if { [string equal $cpu_type "TMS320C6410"] ||
     [string equal $cpu_type "TMS320C6710"] } {

  puts "Initializing MCBSP controller to clock-stop mode (@$ctrlr_base)..." 

  set divisor [expr $periph_clock / 1000000]
  puts "Calculated SRGR value is $divisor"

  # SPCR1 = 0x02000000
  PutLong $DEV [expr $ctrlr_base + 0x08] 0 0x02000000
  # pause
  after 10
  # SPCR = 0x00001800
  PutLong $DEV [expr $ctrlr_base + 0x08] 0 0x00001800
  # PCR = 0x0A09
  PutLong $DEV [expr $ctrlr_base + 0x24] 0 0x00000A09
  # RCR = 0x00010000
  PutLong $DEV [expr $ctrlr_base + 0x0C] 0 0x00010000
  # XCR = 0x00010000
  PutLong $DEV [expr $ctrlr_base + 0x10] 0 0x00010000
  # SRGR = 0x200000xx
  PutLong $DEV [expr $ctrlr_base + 0x14] 0 [expr $divisor | 0x20000000]
  # MCR = 0
  PutLong $DEV [expr $ctrlr_base + 0x18] 0 0x00000000
  # pause
  after 50
  # SPCR = 0x02401800
  PutLong $DEV [expr $ctrlr_base + 0x08] 0 0x02401800
  # pause
  after 50
  # SPCR = 0x02411801
  PutLong $DEV [expr $ctrlr_base + 0x08] 0 0x02411801

}
